diff --git a/Documentation/NuttXDemandPaging.html b/Documentation/NuttXDemandPaging.html index 4215ebc160..e3a682c8b2 100644 --- a/Documentation/NuttXDemandPaging.html +++ b/Documentation/NuttXDemandPaging.html @@ -8,7 +8,7 @@
Last Updated: February 4, 2010
+Last Updated: February 4, 2019
- During OS initialization in sched/os_start.c
, the following steps
+ During OS initialization in sched/init/nx_start.c
, the following steps
will be performed:
Last Updated: August 25, 2018
+Last Updated: February 4, 2019
@@ -150,7 +150,7 @@os_start()
nx_start()
sched_process_timer()
sched_timer_expiration()
os_start()
nx_start()
To be provided
@@ -6649,7 +6649,7 @@ int syslog_initialize(enum syslog_init_e phase);
- syslog_initialize()
is called again from os_start()
when the full OS initialization has completed, just before the application main entry point is spawned. In this case, syslog_initialize()
is called with the argument SYSLOG_INIT_LATE
.
+ syslog_initialize()
is called again from nx_start()
when the full OS initialization has completed, just before the application main entry point is spawned. In this case, syslog_initialize()
is called with the argument SYSLOG_INIT_LATE
.
diff --git a/TODO b/TODO
index fbfaf890b3..bcb030a2eb 100644
--- a/TODO
+++ b/TODO
@@ -296,9 +296,9 @@ o Task/Scheduler (sched/)
1. One problem is stack-related data in the IDLE threads TCB.
A solution might be to standardize the use of g_idle_topstack.
- That you could add initialization like this in os_start:
+ That you could add initialization like this in nx_start:
- @@ -344,6 +347,11 @@ void os_start(void)
+ @@ -344,6 +347,11 @@ void nx_start(void)
g_idleargv[1] = NULL;
g_idletcb.argv = g_idleargv;
@@ -335,18 +335,18 @@ o Task/Scheduler (sched/)
2. Another problem is colorizing that stack to use with
stack usage monitoring logic. There is logic in some
- start functions to do this in a function called go_os_start.
+ start functions to do this in a function called go_nx_start.
It is available in these architectures:
- ./arm/src/efm32/efm32_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/kinetis/kinetis_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/sam34/sam_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/samv7/sam_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/stm32/stm32_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/stm32f7/stm32_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/stm32l4/stm32l4_start.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/tms570/tms570_boot.c:static void go_os_start(void *pv, unsigned int nbytes)
- ./arm/src/xmc4/xmc4_start.c:static void go_os_start(void *pv, unsigned int nbytes)
+ ./arm/src/efm32/efm32_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/kinetis/kinetis_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/sam34/sam_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/samv7/sam_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/stm32/stm32_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/stm32f7/stm32_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/stm32l4/stm32l4_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/tms570/tms570_boot.c:static void go_nx_start(void *pv, unsigned int nbytes)
+ ./arm/src/xmc4/xmc4_start.c:static void go_nx_start(void *pv, unsigned int nbytes)
But no others.
Status: Open
diff --git a/arch/arm/src/arm/up_head.S b/arch/arm/src/arm/up_head.S
index 37652bc520..3b55970815 100644
--- a/arch/arm/src/arm/up_head.S
+++ b/arch/arm/src/arm/up_head.S
@@ -630,7 +630,7 @@ __start:
/* Finally branch to the OS entry point */
mov lr, #0 /* LR = return address (none) */
- b os_start /* Branch to os_start */
+ b nx_start /* Branch to nx_start */
/* Text-section constants:
*
diff --git a/arch/arm/src/arm/up_nommuhead.S b/arch/arm/src/arm/up_nommuhead.S
index d8689d85bd..b5f7ea65ad 100644
--- a/arch/arm/src/arm/up_nommuhead.S
+++ b/arch/arm/src/arm/up_nommuhead.S
@@ -147,7 +147,7 @@ __start:
/* Finally branch to the OS entry point */
mov lr, #0 /* LR = return address (none) */
- b os_start /* Branch to os_start */
+ b nx_start /* Branch to nx_start */
/* Variables:
* _sbss is the start of the BSS region (see ld.script)
diff --git a/arch/arm/src/armv7-a/arm_head.S b/arch/arm/src/armv7-a/arm_head.S
index 27c2a5b4dc..2038433296 100644
--- a/arch/arm/src/armv7-a/arm_head.S
+++ b/arch/arm/src/armv7-a/arm_head.S
@@ -665,7 +665,7 @@ __start:
/* Finally branch to the OS entry point */
mov lr, #0 /* LR = return address (none) */
- b os_start /* Branch to os_start */
+ b nx_start /* Branch to nx_start */
.size .Lvstart, .-.Lvstart
/***************************************************************************
diff --git a/arch/arm/src/armv7-a/arm_pghead.S b/arch/arm/src/armv7-a/arm_pghead.S
index 1dda0acdd9..99fd16a6d7 100644
--- a/arch/arm/src/armv7-a/arm_pghead.S
+++ b/arch/arm/src/armv7-a/arm_pghead.S
@@ -697,7 +697,7 @@ __start:
/* Finally branch to the OS entry point */
mov lr, #0 /* LR = return address (none) */
- b os_start /* Branch to os_start */
+ b nx_start /* Branch to nx_start */
.size .Lvstart, .-.Lvstart
/***************************************************************************
diff --git a/arch/arm/src/armv7-r/arm.h b/arch/arm/src/armv7-r/arm.h
index a2d64dc50f..7bee4a0287 100644
--- a/arch/arm/src/armv7-r/arm.h
+++ b/arch/arm/src/armv7-r/arm.h
@@ -133,7 +133,7 @@ extern "C"
* among other things, must initialize memories. After initializatino
( of the memories, this function will call arm_data_initialize() to
* initialize the memory resources
- * 4. This function will then branch to os_start() to start the operating
+ * 4. This function will then branch to nx_start() to start the operating
* system.
*
****************************************************************************/
diff --git a/arch/arm/src/armv7-r/arm_head.S b/arch/arm/src/armv7-r/arm_head.S
index 391416e992..2fd0fbda07 100644
--- a/arch/arm/src/armv7-r/arm_head.S
+++ b/arch/arm/src/armv7-r/arm_head.S
@@ -384,10 +384,10 @@ __start:
* within arm_boot() must configure SDRAM and call arm_data_initialize()
* if CONFIG_ARMV7R_MEMINIT=y.
*
- * This function does not return. It must give control to os_start()
+ * This function does not return. It must give control to nx_start()
* at the completion of its initialization.
*
- * Why not just call arm_boot() and branch to os_start() when it returns?
+ * Why not just call arm_boot() and branch to nx_start() when it returns?
* If the stack pointer initialized above lies in SDRAM, then that may
* not be possible. Also, in the special case of the TMS570, it may
* perform a destructive test, losing the pushed content of the stack.
diff --git a/arch/arm/src/imx6/imx_serial.c b/arch/arm/src/imx6/imx_serial.c
index ff3942c223..5145f5d6b9 100644
--- a/arch/arm/src/imx6/imx_serial.c
+++ b/arch/arm/src/imx6/imx_serial.c
@@ -962,7 +962,7 @@ int up_putc(int ch)
locked = false;
- if (!up_interrupt_context() && g_os_initstate >= OSINIT_HARDWARE)
+ if (!up_interrupt_context() && g_nx_initstate >= OSINIT_HARDWARE)
{
ret = nxsem_wait(&g_putc_lock);
if (ret < 0)
diff --git a/arch/arm/src/kl/kl_start.c b/arch/arm/src/kl/kl_start.c
index 5244365a2a..27c1a71b81 100644
--- a/arch/arm/src/kl/kl_start.c
+++ b/arch/arm/src/kl/kl_start.c
@@ -177,7 +177,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shoulnd't get here */
diff --git a/arch/arm/src/lc823450/lc823450_cpustart.c b/arch/arm/src/lc823450/lc823450_cpustart.c
index d3aa51cced..40f4a712c6 100644
--- a/arch/arm/src/lc823450/lc823450_cpustart.c
+++ b/arch/arm/src/lc823450/lc823450_cpustart.c
@@ -138,7 +138,7 @@ static void cpu1_boot(void)
/* Then transfer control to the IDLE task */
- (void)os_idle_task(0, NULL);
+ (void)nx_idle_task(0, NULL);
}
diff --git a/arch/arm/src/lpc11xx/lpc11_start.c b/arch/arm/src/lpc11xx/lpc11_start.c
index 51dac5d00b..03199227e9 100644
--- a/arch/arm/src/lpc11xx/lpc11_start.c
+++ b/arch/arm/src/lpc11xx/lpc11_start.c
@@ -168,7 +168,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/lpc17xx/lpc17_start.c b/arch/arm/src/lpc17xx/lpc17_start.c
index 0c4ff76d9b..41a6e57bfa 100644
--- a/arch/arm/src/lpc17xx/lpc17_start.c
+++ b/arch/arm/src/lpc17xx/lpc17_start.c
@@ -290,7 +290,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/lpc214x/lpc214x_head.S b/arch/arm/src/lpc214x/lpc214x_head.S
index c0d6c76510..f6d16516af 100644
--- a/arch/arm/src/lpc214x/lpc214x_head.S
+++ b/arch/arm/src/lpc214x/lpc214x_head.S
@@ -597,7 +597,7 @@ __start:
/* Then jump to OS entry */
- b os_start
+ b nx_start
/* Variables:
* _sbss is the start of the BSS region (see ld.script)
diff --git a/arch/arm/src/lpc2378/lpc23xx_head.S b/arch/arm/src/lpc2378/lpc23xx_head.S
index 551f2d240e..6e9eab906a 100644
--- a/arch/arm/src/lpc2378/lpc23xx_head.S
+++ b/arch/arm/src/lpc2378/lpc23xx_head.S
@@ -198,7 +198,7 @@ __start:
/* Then jump to OS entry */
- b os_start
+ b nx_start
/* Variables:
* _sbss is the start of the BSS region (see ld.script)
diff --git a/arch/arm/src/lpc43xx/lpc43_start.c b/arch/arm/src/lpc43xx/lpc43_start.c
index 48684eddd8..91ab197e97 100644
--- a/arch/arm/src/lpc43xx/lpc43_start.c
+++ b/arch/arm/src/lpc43xx/lpc43_start.c
@@ -352,7 +352,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/lpc54xx/lpc54_start.c b/arch/arm/src/lpc54xx/lpc54_start.c
index 2ff749b68a..89c818b102 100644
--- a/arch/arm/src/lpc54xx/lpc54_start.c
+++ b/arch/arm/src/lpc54xx/lpc54_start.c
@@ -275,7 +275,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/max326xx/common/max326_start.c b/arch/arm/src/max326xx/common/max326_start.c
index 28d556d28e..f8321c16e6 100644
--- a/arch/arm/src/max326xx/common/max326_start.c
+++ b/arch/arm/src/max326xx/common/max326_start.c
@@ -281,7 +281,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/nrf52/nrf52_start.c b/arch/arm/src/nrf52/nrf52_start.c
index bb9d5f068e..ff145f7b03 100644
--- a/arch/arm/src/nrf52/nrf52_start.c
+++ b/arch/arm/src/nrf52/nrf52_start.c
@@ -256,7 +256,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/nuc1xx/nuc_start.c b/arch/arm/src/nuc1xx/nuc_start.c
index e38e08caab..bf700a4452 100644
--- a/arch/arm/src/nuc1xx/nuc_start.c
+++ b/arch/arm/src/nuc1xx/nuc_start.c
@@ -169,7 +169,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shoulnd't get here */
diff --git a/arch/arm/src/sam34/sam4cm_cpustart.c b/arch/arm/src/sam34/sam4cm_cpustart.c
index 591760b8c7..33dd5ef47a 100644
--- a/arch/arm/src/sam34/sam4cm_cpustart.c
+++ b/arch/arm/src/sam34/sam4cm_cpustart.c
@@ -134,7 +134,7 @@ static void cpu1_boot(void)
/* Then transfer control to the IDLE task */
- (void)os_idle_task(0, NULL);
+ (void)nx_idle_task(0, NULL);
}
/****************************************************************************
diff --git a/arch/arm/src/samd2l2/sam_start.c b/arch/arm/src/samd2l2/sam_start.c
index 1fca497c68..07c016ae0b 100644
--- a/arch/arm/src/samd2l2/sam_start.c
+++ b/arch/arm/src/samd2l2/sam_start.c
@@ -170,7 +170,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shoulnd't get here */
diff --git a/arch/arm/src/stm32f0l0/stm32_start.c b/arch/arm/src/stm32f0l0/stm32_start.c
index 88cf1a09c7..d63513a792 100644
--- a/arch/arm/src/stm32f0l0/stm32_start.c
+++ b/arch/arm/src/stm32f0l0/stm32_start.c
@@ -160,7 +160,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/str71x/str71x_head.S b/arch/arm/src/str71x/str71x_head.S
index 934fd7fdfd..ea36d3cea5 100644
--- a/arch/arm/src/str71x/str71x_head.S
+++ b/arch/arm/src/str71x/str71x_head.S
@@ -70,7 +70,7 @@
#ifdef CONFIG_DEBUG_FEATURES
.globl up_lowputc /* Low-level debug output */
#endif
- .globl os_start /* NuttX entry point */
+ .globl nx_start /* NuttX entry point */
/*****************************************************************************
* Macros
@@ -577,7 +577,7 @@ ctor_end:
/* Then jump to OS entry */
- b os_start
+ b nx_start
/* Call destructors -- never get here */
diff --git a/arch/arm/src/tiva/cc13xx/cc13xx_start.c b/arch/arm/src/tiva/cc13xx/cc13xx_start.c
index 4197f273dd..4e7fac71ac 100644
--- a/arch/arm/src/tiva/cc13xx/cc13xx_start.c
+++ b/arch/arm/src/tiva/cc13xx/cc13xx_start.c
@@ -304,7 +304,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/arm/src/tiva/common/lmxx_tm4c_start.c b/arch/arm/src/tiva/common/lmxx_tm4c_start.c
index a0b83222f2..d09c0fc75e 100644
--- a/arch/arm/src/tiva/common/lmxx_tm4c_start.c
+++ b/arch/arm/src/tiva/common/lmxx_tm4c_start.c
@@ -284,7 +284,7 @@ void __start(void)
showprogress('\r');
showprogress('\n');
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/avr/src/at90usb/at90usb_head.S b/arch/avr/src/at90usb/at90usb_head.S
index 6d850b7f27..bece849d3d 100644
--- a/arch/avr/src/at90usb/at90usb_head.S
+++ b/arch/avr/src/at90usb/at90usb_head.S
@@ -74,7 +74,7 @@
.global _eronly /* Start of .data section in FLASH */
.global _enoinit /* End of uninitialized data. Defined by ld.script */
.global up_lowinit /* Perform low level initialization */
- .global os_start /* NuttX entry point */
+ .global nx_start /* NuttX entry point */
.global vectortab
.global at90usb_int0 /* External interrupt request 0 */
@@ -258,7 +258,7 @@ __do_clear_bss:
/* Now start NuttX */
- call os_start
+ call nx_start
jmp exit
.endfunc
diff --git a/arch/avr/src/atmega/atmega_head.S b/arch/avr/src/atmega/atmega_head.S
index c7804801cc..1bff0c5416 100644
--- a/arch/avr/src/atmega/atmega_head.S
+++ b/arch/avr/src/atmega/atmega_head.S
@@ -76,7 +76,7 @@
.global _eronly /* Start of .data section in FLASH */
.global _enoinit /* End of uninitilized data. Defined by ld.script */
.global up_lowinit /* Perform low level initialization */
- .global os_start /* NuttX entry point */
+ .global nx_start /* NuttX entry point */
.global vectortab
#if defined(CONFIG_ARCH_CHIP_ATMEGA128)
@@ -454,7 +454,7 @@ __do_clear_bss:
/* Now start NuttX */
- call os_start
+ call nx_start
jmp exit
.endfunc
diff --git a/arch/avr/src/avr32/up_nommuhead.S b/arch/avr/src/avr32/up_nommuhead.S
index 149b1f26fd..52f9b14f37 100644
--- a/arch/avr/src/avr32/up_nommuhead.S
+++ b/arch/avr/src/avr32/up_nommuhead.S
@@ -56,7 +56,7 @@
.global _eronly /* Start of .data section in FLASH */
#endif
.global up_lowinit /* Perform low level initialization */
- .global os_start /* NuttX entry point */
+ .global nx_start /* NuttX entry point */
.global vectortab /* Vector base address */
/****************************************************************************
@@ -133,7 +133,7 @@ __start:
/* Then jump to OS entry (will not return) */
- lda.w pc, os_start
+ lda.w pc, nx_start
.Lstackbase:
.word _ebss+CONFIG_IDLETHREAD_STACKSIZE-4
diff --git a/arch/avr/src/common/up_internal.h b/arch/avr/src/common/up_internal.h
index 9cf4c304db..51a230af43 100644
--- a/arch/avr/src/common/up_internal.h
+++ b/arch/avr/src/common/up_internal.h
@@ -142,7 +142,7 @@ void up_addregion(void);
#endif
/* Defined in chip/xxx_lowinit.c. This function is called from the
- * head.S file just before jumping to os_start(). This function
+ * head.S file just before jumping to nx_start(). This function
* performs whatever very low level initialization that is needed
* before the OS gets started (clocks, console, LEDs, etc.)
*/
diff --git a/arch/hc/src/m9s12/m9s12_start.S b/arch/hc/src/m9s12/m9s12_start.S
index f6b54ad58f..7f02996b6b 100644
--- a/arch/hc/src/m9s12/m9s12_start.S
+++ b/arch/hc/src/m9s12/m9s12_start.S
@@ -68,7 +68,7 @@
.file "m9s12_start.S"
.globl __start
- .globl os_start
+ .globl nx_start
.globl up_lowsetup
.globl hcs12_boardinitialize
@@ -224,7 +224,7 @@ __start:
/* Now, start the OS */
showprogress '\n'
- CALL os_start
+ CALL nx_start
bra __start
/* Variables:
diff --git a/arch/mips/src/pic32mx/pic32mx-head.S b/arch/mips/src/pic32mx/pic32mx-head.S
index b5e19f39d8..3de6cd569a 100644
--- a/arch/mips/src/pic32mx/pic32mx-head.S
+++ b/arch/mips/src/pic32mx/pic32mx-head.S
@@ -126,7 +126,7 @@
/* Imported symbols */
- .global os_start
+ .global nx_start
.global pic32mx_exception
.global pic32mx_decodeirq
#ifdef CONFIG_PIC32MX_NMIHANDLER
@@ -575,9 +575,9 @@ __start_nuttx:
jalr ra, t0
nop
- /* Call os_start */
+ /* Call nx_start */
- la t0, os_start
+ la t0, nx_start
jalr ra, t0
nop
diff --git a/arch/mips/src/pic32mz/pic32mz-head.S b/arch/mips/src/pic32mz/pic32mz-head.S
index db012008fe..07cff97933 100644
--- a/arch/mips/src/pic32mz/pic32mz-head.S
+++ b/arch/mips/src/pic32mz/pic32mz-head.S
@@ -127,7 +127,7 @@
/* Imported symbols */
- .global os_start
+ .global nx_start
.global pic32mz_exception
.global pic32mz_decodeirq
#ifdef CONFIG_PIC32MZ_NMIHANDLER
@@ -676,9 +676,9 @@ __start_nuttx:
jalr ra, t0
nop
- /* Call os_start */
+ /* Call nx_start */
- la t0, os_start
+ la t0, nx_start
jalr ra, t0
nop
diff --git a/arch/misoc/src/lm32/lm32_idle.c b/arch/misoc/src/lm32/lm32_idle.c
index 5b85bcc0c0..975684617d 100644
--- a/arch/misoc/src/lm32/lm32_idle.c
+++ b/arch/misoc/src/lm32/lm32_idle.c
@@ -76,7 +76,7 @@ void up_idle(void)
*/
/* This is a kludge that I still don't understand. The call to kmm_trysemaphore()
- * in the os_start.c IDLE loop seems necessary for the good health of the IDLE
+ * in the nx_start.c IDLE loop seems necessary for the good health of the IDLE
* loop. When the work queue is enabled, this logic is removed from the IDLE
* loop and it appears that we are somehow left idling with interrupts non-
* functional. The following should be no-op, it just disables then re-enables
diff --git a/arch/misoc/src/lm32/lm32_vectors.S b/arch/misoc/src/lm32/lm32_vectors.S
index 45407f0db7..2761541162 100644
--- a/arch/misoc/src/lm32/lm32_vectors.S
+++ b/arch/misoc/src/lm32/lm32_vectors.S
@@ -178,7 +178,7 @@ _do_reset:
bi .clearBSS
.callMain:
- bi os_start
+ bi nx_start
.save_all:
addi sp, sp, -136
diff --git a/arch/or1k/src/mor1kx/mor1kx_start.c b/arch/or1k/src/mor1kx/mor1kx_start.c
index 828f007a9b..2b752ea347 100644
--- a/arch/or1k/src/mor1kx/mor1kx_start.c
+++ b/arch/or1k/src/mor1kx/mor1kx_start.c
@@ -131,7 +131,7 @@ void __start(void)
/* Start NuttX */
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/renesas/src/m16c/m16c_head.S b/arch/renesas/src/m16c/m16c_head.S
index 2ed97e4853..e959feee06 100644
--- a/arch/renesas/src/m16c/m16c_head.S
+++ b/arch/renesas/src/m16c/m16c_head.S
@@ -267,8 +267,8 @@ __start:
/* Pass control to NuttX */
- .globl _os_start
- jsr.a _os_start
+ .globl _nx_start
+ jsr.a _nx_start
/* NuttX will not return, but just in case... */
diff --git a/arch/renesas/src/sh1/sh1_head.S b/arch/renesas/src/sh1/sh1_head.S
index 695e0d8653..29be312eba 100644
--- a/arch/renesas/src/sh1/sh1_head.S
+++ b/arch/renesas/src/sh1/sh1_head.S
@@ -70,7 +70,7 @@
#ifdef CONFIG_DEBUG_FEATURES
.globl _up_lowputc /* Low-level debug output */
#endif
- .globl _os_start /* NuttX entry point */
+ .globl _nx_start /* NuttX entry point */
/* Variables set up by the linker script */
@@ -495,7 +495,7 @@ __start0:
.Lledinit:
.long _board_autoled_initialize
.Losstart:
- .long _os_start
+ .long _nx_start
.Lsvect:
.long _svect
.Lvectend:
diff --git a/arch/risc-v/src/common/up_idle.c b/arch/risc-v/src/common/up_idle.c
index 0c8a867d79..7ec8fb48a2 100644
--- a/arch/risc-v/src/common/up_idle.c
+++ b/arch/risc-v/src/common/up_idle.c
@@ -75,7 +75,7 @@ void up_idle(void)
*/
/* This is a kludge that I still don't understand. The call to kmm_trysemaphore()
- * in the os_start.c IDLE loop seems necessary for the good health of the IDLE
+ * in the nx_start.c IDLE loop seems necessary for the good health of the IDLE
* loop. When the work queue is enabled, this logic is removed from the IDLE
* loop and it appears that we are somehow left idling with interrupts non-
* functional. The following should be no-op, it just disables then re-enables
diff --git a/arch/risc-v/src/common/up_internal.h b/arch/risc-v/src/common/up_internal.h
index bacf39c780..011f00d510 100644
--- a/arch/risc-v/src/common/up_internal.h
+++ b/arch/risc-v/src/common/up_internal.h
@@ -153,7 +153,7 @@ void up_lowputs(const char *str);
/* The OS start routine **************************************************/
-void os_start(void);
+void nx_start(void);
#undef EXTERN
#ifdef __cplusplus
diff --git a/arch/risc-v/src/nr5m100/nr5_head.S b/arch/risc-v/src/nr5m100/nr5_head.S
index e41ddc39d5..6bc69616d5 100644
--- a/arch/risc-v/src/nr5m100/nr5_head.S
+++ b/arch/risc-v/src/nr5m100/nr5_head.S
@@ -83,7 +83,7 @@
.extern __reset_vec
.extern __trap_vec
.extern __stack_start
- .global os_start
+ .global nx_start
#ifndef CONFIG_LIB_NEWLIB
diff --git a/arch/risc-v/src/nr5m100/nr5_init.c b/arch/risc-v/src/nr5m100/nr5_init.c
index a296ad5a13..b49c32b622 100644
--- a/arch/risc-v/src/nr5m100/nr5_init.c
+++ b/arch/risc-v/src/nr5m100/nr5_init.c
@@ -64,9 +64,9 @@ void __nr5_init(void)
nr5_boardinitialize();
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
diff --git a/arch/sim/src/up_head.c b/arch/sim/src/up_head.c
index b57012ed6c..c163c1871d 100644
--- a/arch/sim/src/up_head.c
+++ b/arch/sim/src/up_head.c
@@ -98,7 +98,7 @@ int main(int argc, char **argv, char **envp)
#else
/* Start the Nuttx emulation. This should not return. */
- os_start();
+ nx_start();
#endif
}
diff --git a/arch/xtensa/src/common/xtensa_idle.c b/arch/xtensa/src/common/xtensa_idle.c
index 894cdb606b..162574405e 100644
--- a/arch/xtensa/src/common/xtensa_idle.c
+++ b/arch/xtensa/src/common/xtensa_idle.c
@@ -75,7 +75,7 @@ void up_idle(void)
*/
/* This is a kludge that I still don't understand. The call to kmm_trysemaphore()
- * in the os_start.c IDLE loop seems necessary for the good health of the IDLE
+ * in the nx_start.c IDLE loop seems necessary for the good health of the IDLE
* loop. When the work queue is enabled, this logic is removed from the IDLE
* loop and it appears that we are somehow left idling with interrupts non-
* functional. The following should be no-op, it just disables then re-enables
diff --git a/arch/xtensa/src/esp32/esp32_start.c b/arch/xtensa/src/esp32/esp32_start.c
index b0d9a58443..799e809566 100644
--- a/arch/xtensa/src/esp32/esp32_start.c
+++ b/arch/xtensa/src/esp32/esp32_start.c
@@ -152,6 +152,6 @@ void IRAM_ATTR __start(void)
/* Bring up NuttX */
- os_start();
+ nx_start();
for(; ; ); /* Should not return */
}
diff --git a/arch/z80/src/ez80/ez80_startup.asm b/arch/z80/src/ez80/ez80_startup.asm
index af17398132..8f8da39f77 100644
--- a/arch/z80/src/ez80/ez80_startup.asm
+++ b/arch/z80/src/ez80/ez80_startup.asm
@@ -61,7 +61,7 @@
xref __len_code
xref __low_code
xref __low_romcode
- xref _os_start
+ xref _nx_start
xdef _ez80_startup
xdef _ez80_halt
@@ -145,7 +145,7 @@ _ez80_codedone:
; Then start NuttX
- call _os_start ; jump to the OS entry point
+ call _nx_start ; jump to the OS entry point
; NuttX will never return, but just in case...
diff --git a/arch/z80/src/z180/z180_head.asm b/arch/z80/src/z180/z180_head.asm
index 2ecbefe246..f28906eaa2 100644
--- a/arch/z80/src/z180/z180_head.asm
+++ b/arch/z80/src/z180/z180_head.asm
@@ -48,7 +48,7 @@
; Global symbols used
;**************************************************************************
- .globl _os_start ; OS entry point
+ .globl _nx_start ; OS entry point
.globl _up_vectcommon ; Common interrupt handling logic
.globl _z180_mmu_lowinit ; MMU initialization logic
.globl s__HEAP ; Start of the heap
@@ -159,7 +159,7 @@ _up_reset:
; Then start NuttX
- call _os_start ; jump to the OS entry point
+ call _nx_start ; jump to the OS entry point
; NuttX will never return, but just in case...
diff --git a/arch/z80/src/z180/z180_rom.asm b/arch/z80/src/z180/z180_rom.asm
index 8a7a62a545..2906294685 100644
--- a/arch/z80/src/z180/z180_rom.asm
+++ b/arch/z80/src/z180/z180_rom.asm
@@ -48,7 +48,7 @@
; Global symbols used
;**************************************************************************
- .globl _os_start ; OS entry point
+ .globl _nx_start ; OS entry point
.globl _up_vectcommon ; Common interrupt handling logic
.globl _z180_mmu_lowinit ; MMU initialization logic
.globl s__HEAP ; Start of the heap
@@ -76,7 +76,7 @@ _up_reset:
; Then start NuttX
- call _os_start ; jump to the OS entry point
+ call _nx_start ; jump to the OS entry point
; NuttX will never return, but just in case...
diff --git a/arch/z80/src/z8/z8_head.S b/arch/z80/src/z8/z8_head.S
index a211e27021..967ba07318 100644
--- a/arch/z80/src/z8/z8_head.S
+++ b/arch/z80/src/z8/z8_head.S
@@ -70,7 +70,7 @@
#ifdef CONFIG_ARCH_LEDS
xref _board_autoled_initialize:ROM
#endif
- xref _os_start:ROM
+ xref _nx_start:ROM
xref _up_doirq:ROM
xref _low_nearbss
xref _len_nearbss
@@ -225,7 +225,7 @@ _z8_reset10:
ldx __intrp,#0
xor r15, r15
xor r14, r14
- call _os_start
+ call _nx_start
/* We should never get here */
diff --git a/arch/z80/src/z80/z80_head.asm b/arch/z80/src/z80/z80_head.asm
index 4dadc5ba40..0febd3df2b 100644
--- a/arch/z80/src/z80/z80_head.asm
+++ b/arch/z80/src/z80/z80_head.asm
@@ -60,7 +60,7 @@
; Global symbols used
;**************************************************************************
- .globl _os_start ; OS entry point
+ .globl _nx_start ; OS entry point
.globl _up_doirq ; Interrupt decoding logic
;**************************************************************************
@@ -174,7 +174,7 @@ _up_reset:
; Then start NuttX
- call _os_start ; jump to the OS entry point
+ call _nx_start ; jump to the OS entry point
; NuttX will never return, but just in case...
diff --git a/arch/z80/src/z80/z80_rom.asm b/arch/z80/src/z80/z80_rom.asm
index abc450bcd8..16ef4111ab 100644
--- a/arch/z80/src/z80/z80_rom.asm
+++ b/arch/z80/src/z80/z80_rom.asm
@@ -60,7 +60,7 @@
; Global symbols used
;**************************************************************************
- .globl _os_start ; OS entry point
+ .globl _nx_start ; OS entry point
.globl _up_doirq ; Interrupt decoding logic
;**************************************************************************
@@ -86,7 +86,7 @@ _up_reset:
; Then start NuttX
- call _os_start ; jump to the OS entry point
+ call _nx_start ; jump to the OS entry point
; NuttX will never return, but just in case...
diff --git a/configs/ea3131/locked/Makefile b/configs/ea3131/locked/Makefile
index 2060abf52e..5c33bc2be0 100644
--- a/configs/ea3131/locked/Makefile
+++ b/configs/ea3131/locked/Makefile
@@ -91,7 +91,7 @@ locked.r: ld-locked.inc $(PASS1_LIBBOARD)
@echo "LD: locked.r"
$(Q) $(LD) -o $@ $(PASS1_LDFLAGS) $(PASS1_LIBPATHS) --start-group $(PASS1_LDLIBS) --end-group $(PASS1_LIBGCC)
$(Q) $(NM) $@ > locked.map
- $(Q) fgrep " U " locked.map | grep -v os_start
+ $(Q) fgrep " U " locked.map | grep -v nx_start
$(Q) $(CROSSDEV)size $@
$(PASS1_SRCDIR)$(DELIM)locked.r: locked.r
diff --git a/configs/ea3131/src/lpc31_fillpage.c b/configs/ea3131/src/lpc31_fillpage.c
index 0193dc2c9d..1e39df1b35 100644
--- a/configs/ea3131/src/lpc31_fillpage.c
+++ b/configs/ea3131/src/lpc31_fillpage.c
@@ -516,7 +516,7 @@ void weak_function lpc31_pginitialize(void)
* that it is called.
*
* In reality, however, this function is not very useful: This function is called
- * from a low level (before os_start() is even called), it may not be possible to
+ * from a low level (before nx_start() is even called), it may not be possible to
* perform file system operations or even to get debug output yet. Therefore,
* to keep life simple, initialization will be deferred in all cases until the first
* time that up_fillpage() is called.
diff --git a/configs/ea3152/src/lpc31_fillpage.c b/configs/ea3152/src/lpc31_fillpage.c
index 52d220da0b..c5943a9252 100644
--- a/configs/ea3152/src/lpc31_fillpage.c
+++ b/configs/ea3152/src/lpc31_fillpage.c
@@ -515,7 +515,7 @@ void weak_function lpc31_pginitialize(void)
* that it is called.
*
* In reality, however, this function is not very useful: This function is called
- * from a low level (before os_start() is even called), it may not be possible to
+ * from a low level (before nx_start() is even called), it may not be possible to
* perform file system operations or even to get debug output yet. Therefore,
* to keep life simple, initialization will be deferred in all cases until the first
* time that up_fillpage() is called.
diff --git a/configs/max32660-evsys/README.txt b/configs/max32660-evsys/README.txt
index 5a7ee35857..f1301377b6 100644
--- a/configs/max32660-evsys/README.txt
+++ b/configs/max32660-evsys/README.txt
@@ -171,7 +171,7 @@ Debugging from FLASH:
(gdb) mon reset
(gdb) mon reg pc __start # Set PC to __start entry point
(gdb) file nuttx
- (gdb) b os_start
+ (gdb) b nx_start
(gdb) c
Also not very reliable.
@@ -187,7 +187,7 @@ Debugging from SRAM:
(gdb) load nuttx # Re-load code into SRAM
(gdb) mon reg pc __start # Set PC to __start entry point
(gdb) file nuttx
- (gdb) b os_start
+ (gdb) b nx_start
(gdb) c
Recovering from bad code in FLASH:
diff --git a/configs/sam4e-ek/tools/gdb.ini b/configs/sam4e-ek/tools/gdb.ini
index 594fcf8bc3..bc7afd25c3 100644
--- a/configs/sam4e-ek/tools/gdb.ini
+++ b/configs/sam4e-ek/tools/gdb.ini
@@ -1,6 +1,6 @@
target remote localhost:3333
file nuttx
-b os_start
+b nx_start
mon at91sam4 gpnvm set 1
load
mon reset init
diff --git a/drivers/syslog/README.txt b/drivers/syslog/README.txt
index c0adaaa8da..024e4ce434 100644
--- a/drivers/syslog/README.txt
+++ b/drivers/syslog/README.txt
@@ -227,7 +227,7 @@ SYSLOG Channels
up_initialize() function as some as basic hardware resources have been
initialized: Timers, interrupts, etc. In this case,
syslog_initialize() is called with the argument SYSLOG_INIT_EARLY.
- * syslog_initialize() is called again from os_start() when the full OS
+ * syslog_initialize() is called again from nx_start() when the full OS
initialization has completed, just before the application main entry
point is spawned. In this case, syslog_initialize() is called with
the argument SYSLOG_INIT_LATE.
diff --git a/include/nuttx/init.h b/include/nuttx/init.h
index 54eb9033d0..ff7350e1fb 100644
--- a/include/nuttx/init.h
+++ b/include/nuttx/init.h
@@ -52,10 +52,10 @@
* initialization.
*/
-#define OSINIT_MM_READY() (g_os_initstate >= OSINIT_MEMORY)
-#define OSINIT_HW_READY() (g_os_initstate >= OSINIT_HARDWARE)
-#define OSINIT_OS_READY() (g_os_initstate >= OSINIT_OSREADY)
-#define OSINIT_OS_INITIALIZING() (g_os_initstate < OSINIT_OSREADY)
+#define OSINIT_MM_READY() (g_nx_initstate >= OSINIT_MEMORY)
+#define OSINIT_HW_READY() (g_nx_initstate >= OSINIT_HARDWARE)
+#define OSINIT_OS_READY() (g_nx_initstate >= OSINIT_OSREADY)
+#define OSINIT_OS_INITIALIZING() (g_nx_initstate < OSINIT_OSREADY)
/****************************************************************************
* Public Types
@@ -63,7 +63,7 @@
/* Initialization state. OS bring-up occurs in several phases: */
-enum os_initstate_e
+enum nx_initstate_e
{
OSINIT_POWERUP = 0, /* Power-up. No initialization yet performed.
* Depends on .bss initialization logic for this
@@ -100,7 +100,7 @@ extern "C"
* hardware resources may not yet be available to the OS-internal logic.
*/
-EXTERN uint8_t g_os_initstate; /* See enum os_initstate_e */
+EXTERN uint8_t g_nx_initstate; /* See enum nx_initstate_e */
/****************************************************************************
* Public Function Prototypes
@@ -110,10 +110,10 @@ EXTERN uint8_t g_os_initstate; /* See enum os_initstate_e */
int CONFIG_USER_ENTRYPOINT(int argc, char *argv[]);
-/* Functions contained in os_task.c *****************************************/
+/* Functions contained in nx_task.c *****************************************/
/* OS entry point called by boot logic */
-void os_start(void) noreturn_function;
+void nx_start(void) noreturn_function;
#undef EXTERN
#ifdef __cplusplus
diff --git a/include/nuttx/syslog/syslog.h b/include/nuttx/syslog/syslog.h
index 2dc54e7fe1..daad5d3b3d 100644
--- a/include/nuttx/syslog/syslog.h
+++ b/include/nuttx/syslog/syslog.h
@@ -101,7 +101,7 @@ enum syslog_init_e
{
SYSLOG_INIT_RESET = 0, /* Power on SYSLOG initializaton phase */
SYSLOG_INIT_EARLY, /* Early initialization in up_initialize() */
- SYSLOG_INIT_LATE /* Late initialization in os_start(). */
+ SYSLOG_INIT_LATE /* Late initialization in nx_start(). */
};
/* This structure provides the interface to a SYSLOG device */
diff --git a/mm/umm_heap/umm_initialize.c b/mm/umm_heap/umm_initialize.c
index 78eff2d5ab..3fcbd3f85f 100644
--- a/mm/umm_heap/umm_initialize.c
+++ b/mm/umm_heap/umm_initialize.c
@@ -61,7 +61,7 @@
* kernel and application code. There is only one heap that use is
* used by both the kernel and application logic.
*
- * In this configuration, this function is called early in os_start()
+ * In this configuration, this function is called early in nx_start()
* to initialize the common heap.
*
* CONFIG_BUILD_PROTECTED
@@ -72,7 +72,7 @@
* Or there may be separate protected/kernel and unprotected/user
* heaps.
*
- * In either case, this function is still called early in os_start()
+ * In either case, this function is still called early in nx_start()
* to initialize the user heap.
*
* CONFIG_BUILD_KERNEL
diff --git a/sched/init/Make.defs b/sched/init/Make.defs
index 46c0718c8e..a42a4e5ad5 100644
--- a/sched/init/Make.defs
+++ b/sched/init/Make.defs
@@ -1,7 +1,7 @@
############################################################################
# sched/init/Make.defs
#
-# Copyright (C) 2014 Gregory Nutt. All rights reserved.
+# Copyright (C) 2014, 2019 Gregory Nutt. All rights reserved.
# Author: Gregory Nutt
diff --git a/arch/arm/src/efm32/efm32_start.c b/arch/arm/src/efm32/efm32_start.c
index b24b0a3458..2f8d8be39b 100644
--- a/arch/arm/src/efm32/efm32_start.c
+++ b/arch/arm/src/efm32/efm32_start.c
@@ -99,7 +99,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void efm32_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked,no_instrument_function,noreturn));
#endif
@@ -218,18 +218,18 @@ static inline void efm32_fpuconfig(void)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -253,7 +253,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -339,13 +339,13 @@ void __start(void)
showprogress('\n');
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -218,18 +218,18 @@ static inline void efm32_fpuconfig(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -218,18 +218,18 @@ static inline void efm32_fpuconfig(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/imxrt/imxrt_start.c b/arch/arm/src/imxrt/imxrt_start.c
index c9f9b3a327..347a711a54 100644
--- a/arch/arm/src/imxrt/imxrt_start.c
+++ b/arch/arm/src/imxrt/imxrt_start.c
@@ -92,7 +92,7 @@
static inline void imxrt_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -245,18 +245,18 @@ static inline void imxrt_tcmenable(void)
}
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -280,7 +280,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -390,13 +390,13 @@ void __start(void)
/* Then start NuttX */
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -245,18 +245,18 @@ static inline void imxrt_tcmenable(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -245,18 +245,18 @@ static inline void imxrt_tcmenable(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/kinetis/kinetis_start.c b/arch/arm/src/kinetis/kinetis_start.c
index bcefd3ead9..de7b019428 100644
--- a/arch/arm/src/kinetis/kinetis_start.c
+++ b/arch/arm/src/kinetis/kinetis_start.c
@@ -69,7 +69,7 @@ static inline void kinetis_fpuconfig(void);
#if 0 /* Not used */
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
#endif
@@ -216,19 +216,19 @@ static inline void kinetis_fpuconfig(void)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#if 0 /* Not used */
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -252,7 +252,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -362,7 +362,7 @@ void __start(void)
/* Then start NuttX */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -216,19 +216,19 @@ static inline void kinetis_fpuconfig(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -216,19 +216,19 @@ static inline void kinetis_fpuconfig(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/lc823450/lc823450_start.c b/arch/arm/src/lc823450/lc823450_start.c
index a6890a6b99..eb7e8d4baa 100644
--- a/arch/arm/src/lc823450/lc823450_start.c
+++ b/arch/arm/src/lc823450/lc823450_start.c
@@ -126,7 +126,7 @@ extern uint32_t _stext_sram, _etext_sram, _ftext, _svect;
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -149,18 +149,18 @@ static void go_os_start(void *pv, unsigned int nbytes)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -184,7 +184,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -401,13 +401,13 @@ void __start(void)
CURRENT_REGS = NULL;
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shoulnd't get here */
@@ -149,18 +149,18 @@ static void go_os_start(void *pv, unsigned int nbytes)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -149,18 +149,18 @@ static void go_os_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/sam34/sam_start.c b/arch/arm/src/sam34/sam_start.c
index 654ecac1f7..a711b4c9ff 100644
--- a/arch/arm/src/sam34/sam_start.c
+++ b/arch/arm/src/sam34/sam_start.c
@@ -98,7 +98,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void sam_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -217,18 +217,18 @@ static inline void sam_fpuconfig(void)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -252,7 +252,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -368,14 +368,14 @@ void __start(void)
showprogress('\n');
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -217,18 +217,18 @@ static inline void sam_fpuconfig(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -217,18 +217,18 @@ static inline void sam_fpuconfig(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/samd5e5/sam_start.c b/arch/arm/src/samd5e5/sam_start.c
index f4e7600698..136988bfdb 100644
--- a/arch/arm/src/samd5e5/sam_start.c
+++ b/arch/arm/src/samd5e5/sam_start.c
@@ -99,7 +99,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void sam_fpu_configure(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -218,18 +218,18 @@ static inline void sam_fpu_configure(void)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -253,7 +253,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -363,14 +363,14 @@ void __start(void)
showprogress('\n');
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -218,18 +218,18 @@ static inline void sam_fpu_configure(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -218,18 +218,18 @@ static inline void sam_fpu_configure(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/samv7/sam_start.c b/arch/arm/src/samv7/sam_start.c
index 165c08b827..4c10ece48f 100644
--- a/arch/arm/src/samv7/sam_start.c
+++ b/arch/arm/src/samv7/sam_start.c
@@ -104,7 +104,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void sam_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -258,18 +258,18 @@ static inline void sam_tcmenable(void)
}
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -293,7 +293,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -404,13 +404,13 @@ void __start(void)
/* Then start NuttX */
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -258,18 +258,18 @@ static inline void sam_tcmenable(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -258,18 +258,18 @@ static inline void sam_tcmenable(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/stm32/stm32_start.c b/arch/arm/src/stm32/stm32_start.c
index b38a4ac3a0..2d7a03ecb8 100644
--- a/arch/arm/src/stm32/stm32_start.c
+++ b/arch/arm/src/stm32/stm32_start.c
@@ -96,7 +96,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void stm32_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -219,18 +219,18 @@ static inline void stm32_fpuconfig(void)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -254,7 +254,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -349,13 +349,13 @@ void __start(void)
showprogress('\n');
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shoulnd't get here */
@@ -219,18 +219,18 @@ static inline void stm32_fpuconfig(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -219,18 +219,18 @@ static inline void stm32_fpuconfig(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/stm32f7/stm32_start.c b/arch/arm/src/stm32f7/stm32_start.c
index a84251c7af..92f3c02f64 100644
--- a/arch/arm/src/stm32f7/stm32_start.c
+++ b/arch/arm/src/stm32f7/stm32_start.c
@@ -104,7 +104,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void stm32_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -259,18 +259,18 @@ static inline void stm32_tcmenable(void)
}
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -294,7 +294,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -395,13 +395,13 @@ void __start(void)
/* Then start NuttX */
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -259,18 +259,18 @@ static inline void stm32_tcmenable(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -259,18 +259,18 @@ static inline void stm32_tcmenable(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/stm32h7/stm32_start.c b/arch/arm/src/stm32h7/stm32_start.c
index 7c0341b279..5fd79e79d0 100644
--- a/arch/arm/src/stm32h7/stm32_start.c
+++ b/arch/arm/src/stm32h7/stm32_start.c
@@ -105,7 +105,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void stm32_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -274,18 +274,18 @@ static inline void stm32_tcmenable(void)
}
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -309,7 +309,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -418,13 +418,13 @@ void __start(void)
showprogress('\n');
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -274,18 +274,18 @@ static inline void stm32_tcmenable(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -274,18 +274,18 @@ static inline void stm32_tcmenable(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/stm32l4/stm32l4_start.c b/arch/arm/src/stm32l4/stm32l4_start.c
index d89a41de45..4d85fae6e3 100644
--- a/arch/arm/src/stm32l4/stm32l4_start.c
+++ b/arch/arm/src/stm32l4/stm32l4_start.c
@@ -104,7 +104,7 @@ const uintptr_t g_idle_topstack = HEAP_BASE;
static inline void stm32l4_fpuconfig(void);
#endif
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -227,18 +227,18 @@ static inline void stm32l4_fpuconfig(void)
#endif
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -262,7 +262,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -369,13 +369,13 @@ void __start(void)
showprogress('\n');
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shoulnd't get here */
@@ -227,18 +227,18 @@ static inline void stm32l4_fpuconfig(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -227,18 +227,18 @@ static inline void stm32l4_fpuconfig(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/arm/src/tms570/tms570_boot.c b/arch/arm/src/tms570/tms570_boot.c
index bbaf128b44..242dab4feb 100644
--- a/arch/arm/src/tms570/tms570_boot.c
+++ b/arch/arm/src/tms570/tms570_boot.c
@@ -205,7 +205,7 @@ static void tms570_memory_initialize(uint32_t ramset)
}
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Re-initialize the stack and frame pointers and branch to OS start.
@@ -213,13 +213,13 @@ static void tms570_memory_initialize(uint32_t ramset)
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
naked_function noreturn_function;
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -245,16 +245,16 @@ static void go_os_start(void *pv, unsigned int nbytes)
"\tldr sp, [ip]\n" /* Reset the stack pointer */
"\tmov fp, #0\n" /* Reset the frame pointer */
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#else
-static void go_os_start(void) naked_function noreturn_function;
+static void go_nx_start(void) naked_function noreturn_function;
-static void go_os_start(void)
+static void go_nx_start(void)
{
/* Reset the stack/frame pointer and jump to os_start(). */
__asm__ __volatile__
(
@@ -262,7 +262,7 @@ static void go_os_start(void)
"\tldr sp, [ip]\n" /* Reset the stack pointer */
"\tmov fp, #0\n" /* Reset the frame pointer */
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -291,7 +291,7 @@ static void go_os_start(void)
* things, must initialize SDRAM memory. After initializatino of the
* memories, this function will call arm_data_initialize() to
* initialize the memory resources
* 4. This function will then branch to os_start() to start the operating
* system.
*
****************************************************************************/
@@ -471,12 +471,12 @@ void arm_boot(void)
/* Then start NuttX */
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Branch to os_start(), resetting the stack and frame pointers. */
+ /* Branch to nx_start(), resetting the stack and frame pointers. */
- go_os_start();
+ go_nx_start();
#endif
}
@@ -213,13 +213,13 @@ static void tms570_memory_initialize(uint32_t ramset)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
@@ -245,16 +245,16 @@ static void go_os_start(void *pv, unsigned int nbytes)
{
- /* Reset the stack/frame pointer and jump to os_start(). */
+ /* Reset the stack/frame pointer and jump to nx_start(). */
__asm__ __volatile__
(
@@ -291,7 +291,7 @@ static void go_os_start(void)
* memories, this function will call arm_data_initialize() to
* initialize the memory resources
- * 4. This function will then branch to os_start() to start the operating
+ * 4. This function will then branch to nx_start() to start the operating
* system.
*
diff --git a/arch/arm/src/xmc4/xmc4_start.c b/arch/arm/src/xmc4/xmc4_start.c
index 1d8d7b42a5..3dfd9a731c 100644
--- a/arch/arm/src/xmc4/xmc4_start.c
+++ b/arch/arm/src/xmc4/xmc4_start.c
@@ -70,7 +70,7 @@ static inline void xmc4_fpu_config(void);
static inline void xmc4_unaligned(void);
static inline void xmc4_flash_waitstates(void);
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
__attribute__ ((naked, no_instrument_function, noreturn));
#endif
@@ -256,18 +256,18 @@ static inline void xmc4_flash_waitstates(void)
}
/****************************************************************************
- * Name: go_os_start
+ * Name: go_nx_start
*
* Description:
* Set the IDLE stack to the coloration value and jump into os_start()
*
****************************************************************************/
#ifdef CONFIG_STACK_COLORATION
-static void go_os_start(void *pv, unsigned int nbytes)
+static void go_nx_start(void *pv, unsigned int nbytes)
{
/* Set the IDLE stack to the stack coloration value then jump to
* os_start(). We take extreme care here because were currently
* executing on this stack.
*
* We want to avoid sneak stack access generated by the compiler.
@@ -291,7 +291,7 @@ static void go_os_start(void *pv, unsigned int nbytes)
"2:\n"
"\tmov r14, #0\n" /* LR = return address (none) */
- "\tb os_start\n" /* Branch to os_start */
+ "\tb nx_start\n" /* Branch to nx_start */
);
}
#endif
@@ -397,13 +397,13 @@ void __start(void)
/* Then start NuttX */
#ifdef CONFIG_STACK_COLORATION
- /* Set the IDLE stack to the coloration value and jump into os_start() */
+ /* Set the IDLE stack to the coloration value and jump into nx_start() */
- go_os_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
+ go_nx_start((FAR void *)&_ebss, CONFIG_IDLETHREAD_STACKSIZE);
#else
- /* Call os_start() */
+ /* Call nx_start() */
- os_start();
+ nx_start();
/* Shouldn't get here */
@@ -256,18 +256,18 @@ static inline void xmc4_flash_waitstates(void)
*
* Description:
- * Set the IDLE stack to the coloration value and jump into os_start()
+ * Set the IDLE stack to the coloration value and jump into nx_start()
*
****************************************************************************/
@@ -256,18 +256,18 @@ static inline void xmc4_flash_waitstates(void)
{
/* Set the IDLE stack to the stack coloration value then jump to
- * os_start(). We take extreme care here because were currently
+ * nx_start(). We take extreme care here because were currently
* executing on this stack.
*
diff --git a/arch/risc-v/src/gap8/startup_gap8.S b/arch/risc-v/src/gap8/startup_gap8.S
index 74b0e0b91c..da1a358f0e 100644
--- a/arch/risc-v/src/gap8/startup_gap8.S
+++ b/arch/risc-v/src/gap8/startup_gap8.S
@@ -186,7 +186,7 @@
.extern _idle_stack_end
.extern gap8_dispatch_irq
- .extern os_start
+ .extern nx_start
.extern gapuino_sysinit
/*******************************************************************************
@@ -229,9 +229,9 @@ zero_loop_end:
jal x1, gapuino_sysinit
- /* Directly call Nuttx os_start() */
+ /* Directly call Nuttx nx_start() */
- jal x1, os_start
+ jal x1, nx_start
/* If it ever returns, spin here forever... */
diff --git a/arch/sim/src/up_simsmp.c b/arch/sim/src/up_simsmp.c
index fb7ce5cea9..3a8e688974 100644
--- a/arch/sim/src/up_simsmp.c
+++ b/arch/sim/src/up_simsmp.c
@@ -100,7 +100,7 @@ volatile spinlock_t g_cpu_paused[CONFIG_SMP_NCPUS];
* NuttX domain function prototypes
****************************************************************************/
-void os_start(void) __attribute__ ((noreturn));
+void nx_start(void) __attribute__ ((noreturn));
void up_cpu_paused(int cpu);
void sim_smp_hook(void);
@@ -147,11 +147,11 @@ static void *sim_cpu0_trampoline(void *arg)
return NULL;
}
- /* Give control to os_start() */
+ /* Give control to nx_start() */
- os_start();
+ nx_start();
- /* os_start() should not return */
+ /* nx_start() should not return */
return NULL;
}
diff --git a/arch/x86/src/qemu/qemu_head.S b/arch/x86/src/qemu/qemu_head.S
index 32c3f163af..4e2d04f737 100644
--- a/arch/x86/src/qemu/qemu_head.S
+++ b/arch/x86/src/qemu/qemu_head.S
@@ -76,7 +76,7 @@
****************************************************************************/
.global __start /* Making entry point visible to linker */
- .global os_start /* os_start is defined elsewhere */
+ .global nx_start /* nx_start is defined elsewhere */
.global up_lowsetup /* up_lowsetup is defined elsewhere */
.global g_idle_topstack /* The start of the heap */
@@ -119,7 +119,7 @@ __start:
/* Initialize and start NuttX */
call up_lowsetup /* Low-level, pre-OS initialization */
- call os_start /* Start NuttX */
+ call nx_start /* Start NuttX */
/* NuttX will not return */
diff --git a/arch/z16/src/z16f/z16f_head.S b/arch/z16/src/z16f/z16f_head.S
index 1ceccf9333..dbf631706a 100644
--- a/arch/z16/src/z16f/z16f_head.S
+++ b/arch/z16/src/z16f/z16f_head.S
@@ -61,7 +61,7 @@
#elif defined(USE_EARLYSERIALINIT)
xref _up_earlyserialinit:EROM
#endif
- xref _os_start:EROM
+ xref _nx_start:EROM
xref _up_doirq:EROM
xref _z16f_sysexec:EROM
xdef _z16f_reset
@@ -222,8 +222,8 @@ _z16f_reset8:
#endif
/* Start NuttX */
- call _os_start /* Start the operating system */
-_halt1: /* _os_start() should not return */
+ call _nx_start /* Start the operating system */
+_halt1: /* _nx_start() should not return */
halt
jp _halt1
diff --git a/configs/ea3131/locked/mklocked.sh b/configs/ea3131/locked/mklocked.sh
index f3683be3e5..3dbbd54b3d 100755
--- a/configs/ea3131/locked/mklocked.sh
+++ b/configs/ea3131/locked/mklocked.sh
@@ -144,7 +144,7 @@ fi
echo "EXTERN(arm_boot)" >>ld-locked.inc
# All of the initialization functions that are called by os_start up to
# the point where the page fill worker thread is started must also be
# included in the locked text section (at least for now)
@@ -203,7 +203,7 @@ echo "EXTERN(task_create)" >>ld-locked.inc
#
# The IDLE loop must be forced to lie in the locked .text region.
-echo "EXTERN(os_start)" >>ld-locked.inc
+echo "EXTERN(nx_start)" >>ld-locked.inc
echo "EXTERN(up_idle)" >>ld-locked.inc
############################################################################
@@ -144,7 +144,7 @@ fi
echo "EXTERN(arm_boot)" >>ld-locked.inc
-# All of the initialization functions that are called by os_start up to
+# All of the initialization functions that are called by nx_start up to
# the point where the page fill worker thread is started must also be
# included in the locked text section (at least for now)